import os
import sys
from datetime import datetime
from getpass import getuser
from pathlib import Path
from re import search

import pyautogui


class UkrainianWriter:
    __path = Path('text.txt')
    __notepad_butt = 'buttons/8.png'

    def __init__(self, ukrainian_text: str):
        self.__text = ukrainian_text

    def copy_ukrainian_text(self):
        self.__write_text_into_file()
        self.__open_file_by_notepad()
        self.__copy_text()
        self.__close_notepad()
        self.__delete_text_file()

    def __write_text_into_file(self):
        self.__check_file_exists()
        with open(f'{self.__path}', 'w', encoding='utf-8') as text_file:
            print(self.__text, end='', file=text_file)

    def __open_file_by_notepad(self):
        os.system(f'start notepad {self.__path}')

    def __copy_text(self):
        self.__find_butt(self.__notepad_butt)
        pyautogui.hotkey('ctrl', 'a')
        pyautogui.hotkey('ctrl', 'c')

    @staticmethod
    def __find_butt(butt_name: str) -> None:
        while True:
            butt_cord = pyautogui.locateOnScreen(butt_name)
            if butt_cord is not None:
                break

    @staticmethod
    def __close_notepad():
        pyautogui.hotkey('alt', 'f4')

    def __delete_text_file(self):
        os.remove(self.__path)

    def __check_file_exists(self):
        counter = 0
        while True:
            if not Path(self.__path).exists():
                break
            counter += 1
            self.__set_path(f'text{counter}.txt')

    def __set_path(self, new_path):
        self.__path = Path(new_path)


class ScheduleParser:
    __dir_path = Path('Schedule')
    __file_name = 'Schedule.txt'

    def __init__(self):
        self.__check_directory()
        self.__check_file()

    def __check_file(self) -> None:
        full_file_path = 'Schedule/Schedule.txt'
        list_dir = os.listdir('Schedule')
        if self.__file_name not in list_dir:
            with open(full_file_path, 'w') as _:
                pass
        if not os.path.getsize(full_file_path):
            pyautogui.alert(f'1. Here is an empty "Schedule.txt" file.\n'
                            f'2. Fill "Schedule.txt" file with your info.',
                            title='ATTENTION')
            self.__exit()

    @staticmethod
    def __check_directory() -> None:
        if not Path.is_dir(ScheduleParser.__dir_path):
            Path.mkdir(ScheduleParser.__dir_path)

    @staticmethod
    def __get_full_list(list_to_validate: list[str]) -> list[str]:
        return [row.strip() for row in list_to_validate
                if ('Інд' in row or 'Ст' in row)
                and '-' in row and ':' not in row]

    def __get_list_by_day(self, data_list: list[str]) -> list[str]:
        result_list = []
        week = {
            0: 'MONDAY',
            1: 'TUESDAY',
            2: 'WEDNESDAY',
            3: 'THURSDAY',
            4: 'FRIDAY',
        }
        weekday = week.get(datetime.now().weekday())
        if weekday == 'MONDAY':
            for row in data_list:
                if 'пн' in row or ('ср' in row and row.startswith('Ст')):
                    result_list.append(row)
        elif weekday == 'TUESDAY':
            for row in data_list:
                if 'вт' in row or ('чт' in row and row.startswith('Ст')):
                    result_list.append(row)
        elif weekday == 'WEDNESDAY':
            for row in data_list:
                if 'ср' in row or ('пн' in row and row.startswith('Ст')):
                    result_list.append(row)
        elif weekday == 'THURSDAY':
            for row in data_list:
                if 'чт' in row or ('вт' in row and row.startswith('Ст')):
                    result_list.append(row)
        elif weekday == 'FRIDAY':
            for row in data_list:
                if 'пт' in row:
                    result_list.append(row)
        else:
            pyautogui.alert(f'1. It\'s holiday today.\n'
                            f'2. Run program not on holiday.',
                            title='ATTENTION')
            self.__exit()
        return result_list

    def __get_all_rows_from_file(self) -> list[str]:
        file_path = self.__dir_path.joinpath(self.__file_name)
        with open(file_path, encoding='utf-8') as text_file:
            return text_file.readlines()

    @staticmethod
    def __get_sorted_list(list_to_sort: list[str]) -> list[str]:
        list_to_sort = list(set(list_to_sort))
        pattern = r"[0-9]{2}-[0-9]{2}"
        list_to_sort.sort(key=lambda row: search(pattern, row).group())
        return list_to_sort

    def get_schedule_list(self) -> list[str]:
        all_rows = self.__get_all_rows_from_file()
        full_list = self.__get_full_list(all_rows)
        list_by_day = self.__get_list_by_day(full_list)
        sorted_list = self.__get_sorted_list(list_by_day)
        return sorted_list

    @staticmethod
    def __exit():
        sys.exit()


class ZoomStarter:
    __butt_1 = r'buttons/1.png'
    __butt_2 = r'buttons/2.png'
    __butt_3 = r'buttons/3.png'
    __butt_4 = r'buttons/4.png'
    __butt_5 = r'buttons/5.png'
    __butt_6 = r'buttons/6.png'
    __butt_7 = r'buttons/7.png'

    __schedule_without_free_rooms = ScheduleParser().get_schedule_list()
    __free_rooms = [f'Вільна зала {i}' for i in range(1, 5)]
    __schedule = __schedule_without_free_rooms + __free_rooms

    __schedule_len = len(__schedule)

    def run(self):
        CreateImages().create_buttons_images()
        self.__start_zoom()
        self.__start_conference()
        self.__create_rooms()
        self.__fill_info()
        self.__open_rooms()

    @staticmethod
    def __start_zoom():
        os.system(rf'start C:\Users\{getuser()}\AppData\Roaming\Zoom\bin\Zoom.exe')

    def __start_conference(self):
        self.__click_butt(self.__butt_1)
        self.__click_butt(self.__butt_2)

    def __create_rooms(self):
        self.__click_butt(self.__butt_3)
        self.__click_butt(self.__butt_4)
        self.__click_butt(self.__butt_5)
        self.__enter_count_of_rooms()
        self.__click_butt(self.__butt_6)
        pyautogui.moveTo(1, 1)

    @staticmethod
    def __find_butt(butt_name: str) -> tuple:
        while True:
            butt_cord = pyautogui.locateOnScreen(butt_name)
            if butt_cord is not None:
                return butt_cord

    def __click_butt(self, name: str):
        pyautogui.sleep(0.5)
        pyautogui.click(self.__find_butt(name))

    def __enter_count_of_rooms(self):
        pyautogui.hotkey('ctrl', 'a')
        pyautogui.write(f'{self.__schedule_len}')

    def __fill_info(self):
        for i in range(self.__schedule_len):
            UkrainianWriter(self.__schedule[i]).copy_ukrainian_text()

            pyautogui.press('tab')
            pyautogui.press('down')
            pyautogui.press('tab')
            pyautogui.press('enter')

            pyautogui.hotkey('ctrl', 'v')

            pyautogui.press('enter')

    def __open_rooms(self):
        self.__click_butt(self.__butt_7)
        pyautogui.sleep(0.5)
        pyautogui.press('escape')


class CreateImages:
    __folder_name = Path('buttons')
    __img_1 = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x01e\x00\x00\x00\x12\x08\x06\x00\x00\x00\x83\xd5\xcfv\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x087IDATx^\xed\x9c\xcdk\x1bG\x14\xc0_\xea\xdeBz\xb3\xb6\x9bSh{r+\xe1\xe8\xd2\x12\n!\x8d\x84\xd0\xb9\xc5\x04\x1b\x8c\xfe\x81\x10\x88\x0c>\xd4\x84\x1e\x0cE\x89upBn\xa5(n\x9c\xa4\xa1\xcd\xa5\x07\xe1\xc8N\x9aCJ\xe9A\x18)\xf1\xa9\xa4\xc7\xed\xca\xbe&\xf4\xe6\xbe\xb7;\xeb\xfd\xd0|\xad\xa48\xfe\x98\x1f,\xd6~\xcc\xcc{o\xde\xbcy3Z\xf9\xc4.\x02\x06\x83\xc1`8\x10\xbc\xc7\xfe\x1a\x0c\x06\x83\xe1\x00`\x82\xb2\xc1`0\x1c \xb8A\xb9\xb7~\x0b\xaa\xd5\x05X\xed\xb2\x0b<z\xcf`\t\x9f\xa9\xaen\xb1\x0b\xbal\xc3\xfa\xd2\x02,\xado\x0b\xce\x8f\x12\xc7IW\x15[\xb0Z\xbd\x05\xeb=vjx\x8b\x18[\xeb\xe3\x8f\xc9 \x8e\x05\xb1/v,=\x83\xa8)\x07\x8d\x8f\xdd\xd5\xf0\xdc\xfb\x9c\xa87@\x9a)\xb7\xd7\xf8\x85\x88n\xab\x05`[\xec,\r\xe3P\x98\x9b\x06\xbb\xb9\xcc\x94^\x86\xa6=\rs\x85qv\xff(q\x9ct5\x18\x0e\x1f\xbd\xf5\x07\xde\x98\xac\xcfL\xb0+\x88]\x84\xf9\xfa"\xd4\xbd\xe3\n\x94\xa1\x05\xb5\xeaCH\xc6\xe0a\xe2cvf\x11*v\x0bV8\t\x9a8(\xe7s\x90w:\xd0\xe1\xb6\xba\x05\x9d65\xe8\xfa\xa7\xa9\x99\x80\x99=\xa5\xf1\x88\x1a\xe4\xc8q\x9ct5\x18\x0e\x13[\xd0j\x02\x94\x8b\xb21\x89\x89\xd5l\x11l\xc0X\x18\x8d\xca#\x88\x8f\xd9b\x11\xa0\xf9\xb4/\xd8\x8f}\x87\xb0\xcf{\xbc~\xf5\x17<\x7f\xfd\x05\x94\xec?\xf1o\x16\xce}t\x92\xdd\xf1\xa1\xd9\xe5\x97\x0f.\xc27\xa7\xba\xb0\tY(\xe5\xc2\xcc\x8fR\xfbk\xb7\x7f\x83\xc7\x8f\x9f\xf8\xc7\xce\x87\x91\xfb\xb4T\xf8\x1e\x1e\xbd\x89\xd6\xe9_\xbb\xfd\xc7\x18\x9c=w\x06\xe2-E\xa0\xe5\xc0\xb5\x1f\xe0\xd7\xa0\xden\xf0\xbcN\x9d\xbcg\x98\xac\x8f\xfe\xdbk\x97\x96\x14?\xf5d\xcf\xf0\xeb\tP?\x9b\x94+I\x9a2\xb4D]\x86;\x81=\xf0\xd89\xfd\x15\xe4"\x93s\xbc/^\xc2\xd8\xd9\xcf!\xa8V\xa5\xeb+\xbc\x7f\xfdNXwpt\xc7\xa8\xcc\x1b}9\xbb\x0f\xa1z\xfd>\x96\xed\x82\x03\xaf\xe1\xef\xe7~=qY\xf5\xf4&\x99\xafwC\x7f\n\xf4\xf3e\xc2\'\x92>\xf2x\x07N\x97>\x05j\xc6++\xd4\xc7o3n/<\x04\xbe\xfb\xc9\xab\x1f#\xcf\x85m\xf0P\xca\x1c\xb9\xc6oW\xddW{W\xb5l\xed\x13o3\xea\x1b\xfaz\x8a\xeb\xd0\x939i\x1b\x1f\xf2\xeb\x07\xd0\xe3\xc8\x13\xd6\x95\xf4\r\x9dg8t\x9f\xc2\x1d\xf7c\xf8\xba\x18\xde\xf7b\xdf\xbf\x16|\x19-s\xf2\r\xfc\x836\x85I\xdf\x8e\x83\xc6\xc7^\xf7I<^\x9e<\x03\xa7v\xeeC\xe7D\xbc\x7f\xa4\xdb\x17\xfcH\xbe\r\x9dM\xfe\xecBF\xae5-\xa8\xece\x86\x98\xfa;\xf7\xa4\xfb\xce\xde\xf2\xc1a\'2\\\x17\x1c\xb6\xac\x98/\x8b\x86\x80\x8fv\x9d\xfb\xcc r\t\xcb\xf4\xb6q\xe0\xe5\x98\xad\xa7!\xcf.\x07x}\xb1\x99\x0b\x97a\x15\x0b\x9a\xb5\xfe%\x98\x08Z^y\xe5\xe6)K\xb0\xa0<\xef\x9f\x8b\xb6^xr\xd2 \xac6\\V\x96d\x0c\xea\x99\x06h\xc8\xf7\xd6\x95\xb6\xc2\x00T\xa3,\x07\xeb\x0bd\xeau\\\x98dr\xd2Q\xc9w\xa0\xc1|O\xa5\x8f\xae\xef:\xcdeX\x81K\xec\x19\xd6\x86`o\xb0\x0f\x8e\xcc\x83\x8c\x19\x1eil\xad\xe3\x1b*=\x87\xf5\xafa\xd0\x19GZ\xcf`L\xb1\'\' \xc3\xce\x85xc\xcd\x02+\x11v\xd2\xc6G\x1e\x16V\xda\xee\xc4\xfbZ\xfe\xf6E\xe6<\x94\xb03bi;\xce.M\x0c\x06\xb9\xa4&\x98\xa5\xac\xb51\xab\xafL\xe1\\\x10\xc0R\xff\xf6\x06\xffK\x07,\xb3BNZ\xce\xb1\x0bb\xc8\x80`\x8fk\x18P\xbf\xce}e\x10\xb9\x06\xd5\xc5\xeb\x0b\x1c\x94\xb3\xe7C{e/@\xd9N\xf4\xe5\xa8\xe0\xcaIKC\x17\xfd\xe12\x14\xfa:m\x02f*9\x1c\xf8\xfdK7\x0f\x95\xde\x94\x116:}ug\nS\xb1\xf3l\x0e\xcb\xb7_\xa8\x03\x85g/M\xdf\xcd\xc7\xbf\x13\xa0\x81i\x0b\x97\xb1\x11x2\xa7iWJ\n[\xeb\xfa\x86LO\xdd:\xde\x06*\xdf t\x9eA\\\n\xcaV\xa8#\x1f\xcc\xdck-p\xf2\x17\xfbm\x9b&>\n\xc8\xa0\x8f\xda\xcevlR\x7f\x9f\xfd\x15B\x8e\xddX{\x06\xc5\xac\xdf\x01\xdd\x0e:Vi\xd1\xfb\x1c\xdb1\xa1L\x16\x85)\x85\xde\xe5\x93\x19\xc7\xcc\xc4\xa5\xdb\xf8\xd9\xbf\xe4\x83\xcb\x8b\x95\x16Z\xee\n\x14,RD\x8d\xda\x80\xe9\xebLB\x19B5Y\xd0f\x7f\x19\xc9g\xf2\x95E\x98I\xea\x1dc\x10\xb9\xe4ez\xd8\x0f\xe4(\xdcf\xbd\xbe\xc0\xa3\xb6\xd0W\xcev1c\xca\xfav\xd4\xd1U\x8d@N\x96]L\x8a\x165\xd9\xcf0\x9b\xbb\x87\x0e\x8d\x01)\xa6\x84\xc2V\xce\x06,\xb5)\x00\xf1mN\x19c\r\x03T\x88|`z\xa4\xf0\xdd>\x1f\x14\xfaw\x04\x91\xcc)\xda\x95\xf6U\x1a[\x93_H}\x83}\x96\xe9\xa9\xacc\x94\xfe\x15Eg\x1c\xe9\x8e\xb5mp\x1d\xcc~1\xd9\xed\xc3\xa1/\xf6\xb0\x0e\x86\x8du\xd5#\x13T\x14\xed\xf8\x98\x02y\xa6L\xd0\x0cH\x9b\xdc\xc1\x0c\xe9\x14Q\x00\xff\xd60x\xcb\x0b(\xc2\xac@\xd98\xb4$P\xcfj\xe2:\xc7!\x87\x1e\xeblnEf$\xbf\xce$^\x07\x04K2<x[%\xb1g0\x0bi7\xe4\xaf\x1f\xa5\xd3\xd5G^\xc6\x97=\x9f\x93-\x91\x82\xad\x8d\xf8\x11\xcd~ttU1\x88n2t\xebsh\xf0\xc7\xa0\xbd\xc8\xe4\x92Z# \xef#\xfd2\xeb3\x8a\xbe\nQ\xfb\x86\x9a\xfd\xf1\xaf(:\xbe1\x12\x7f\x8c\xbd}\xa1\xb0\xcb[\x88\x8f\xea\xa0L\xcb\xa9\x92\x05\xcd\x16\x064\x9c\x05@\xb4\x07cY8\tr\x96/\xbc\xfd\x18\xf7\xa9\xbf\xbc\x88.\x7f\xa4\xb0YM\xd6\xa7\x8a:3\x85K\xec\xd5\x16z5\x8d\x8e\x07\xe0\x0e\xf4J_\x02/\x0b\x91\x90ZWDU\xa6\xb7\x05\x9b\x0e.\x91D\x9d/\xea\x8bQ#\x933\x96Yq\xe8\xbe\x80\xf6 ~a_\x84\xb9y\xda\xcb[\x8e\xefI{\xf5a\xa0\x98\x0b\xcbz[^:\xa4\xf0\xdd\xbe\xc0*\xd8o\x8c!\x929E\xbbR\xd2\xd8Z\xd4f\x02\xa9\x9e\x9au\x8c\x14\x1d\xdfH5\xd6\xc6\xc1\xb2%6\xd3F3>\xa6@#(#\x14x\xda\x1b\xb0\xb2iAI4kx\xfb+\x80Yct\xb3\xdf_J$\xf7c\x9c6\n_\xbe\xc4\xd9\xff\xe2\xd3[\xdf\x806oO\'\x82\xbaN4\xde\\8\xfb\xd5\xeb\x97\xa1\xa8\xeb\xf42\x02\x87\x17\xb4\x9bVWB^&X\x9e]\xe0o]\x10\xa2\xbeX\xd5\xfcBJ\x13\xb9\x9c\x13P\xc4\xcc\x88\xbf\x8a\xc0\xac\xb6\xd1\xc1L*^V\xdbV\xa8__\x90K\x06\no_Qs\xc4\xa5\xf0]h\xdf\x8b\xfch@\xf0\x0c\x0f\x9e\xcci\xda\x95\x92\xc2\xd6\xba\xbe!\xd3S\xb7\x8e\x11\xa2\xe3\x1bi\xc7\x1a}\xc96\xcc\xeae\x0f\x9d\xf8(\x02g\x05\'\xf1]\x99rO\xd9\x87:\x1d\x1b\x05I @\xe8\x1b\xeey\xeb\x96\x97\x8d\x06xK\x98\xa4\xa0\xb8<\xd0[^`G/-C\x13\xb3\xc2J]\xf1m\xa6v\x9d\xc3\xc3\xdbS&\xbbp\x1dr\x10\xb9\x84e\x02{\xe0G\x87\xb3_\xd7@\xbb\xb3}K\xef\xe5tX\x80F\x15\x1d\x95A}Q`\x9fG\x82B\xb7L\xe12\xd4\xad\x87P\x8d\xee=\xb2\xcf$K\xdf\xb20\x8d\xad(\xc8U\\\xa86\xd0\x0e\x9b\xb8\xdc\xc4\x0cy\xb6\xdc\x81\x1a\xda\xa0M\xf7\xb1\xae\xf9J\x0e\xcf\xbd\xa7\x95\xe8\xfa\xae]\x9e\x06k\rWZA\xbd\xf9\xc4\x0f\x0fdpd\xd6\x1e3\n\xd2\xd8Z\xc77Tz\x8e\xcc\xbf0\xf8W\xbd\x0eK\x80\xb2\xbb\xd1=x\x1d\xdfH\xe3?H\x86\x82r\x87\x82r:[\xf7\xa3\x17\x1fyx{\xd0\xb9)v\xc6\xa0\xff\x12g8,\xf4v[7\xbe\xdd\xbd\xdba\xa7\t:w\xc5\xf7\xde=/w\xef^\xbd\xb9\xdbr\xd9\xe9\xa1\xc3\xb7\xfd\x8dV\x8f\x9d\x1fd\x86\xb1\xf5\xc1\xd0s\x7f|\x99t}\x87>\xe9\xfe\xbe{\xe3\xea\xcf\xbbI5\xf5\xb6/\x0c\x06\x83\xe1\xc8\x11\xee\x07\xbf\x0b\xe8\xa7\xd8v\xecuH\x1f\x13\x94\x0f\x15\xfe\xbe\xb8\xe8\xf5;ZR\x8a\xee\x19\x0c\x87\x89}\xf3\xe5\xec\x14T \xfd\x8fu\x86\x85~|\xd3\x80i\xae\x8e&(\x1b\x0c\x86c\rM\x00\xfb\xfd?i\xc4m\x02\xfc\x0f0J\xe3\xef\x1b\xc7\t\xad\x00\x00\x00\x00IEND\xaeB`\x82\x97\xcd\xb0g\xfc\xe3q\x88~\xd6\x9b./q\xc2\x88ix\x81>t\xca\x83\x8f\xef^\xe8\xa7^\xc5hp\xd7\xc57\xb4\xf7\xf0/\xc8\x896*\xaf\x0f\xf9\xfb\xe9\x0f\x1bq;\xc7\xea^\x11\xe6\x07\xfdt\xae~Jc\xd3s\x1cv\x95\xaa\xf4=\xfd\xfb+;\x1ewZ\xf5\xf2-\xd2<\xbd\xdahON\xfe\xec4\xf1\x13\xde6\xf2\xe5w\xf4\xc2\xe0\xcfI\xbc\xc6\n\x1b\x98\x1f\xfb\x9d\xee\xf2\xe2#\xa0\xed\xfe\xec\xe1\x9f\x95\xe7\x1a\xef\xf0#2\xcd\xca=\xff\xf7F\xd7U\xfd\xaeVY\xdb\xb8\xdf\xa9\xb6\r\xfd|\x06\xc7\xa1\x97fo\xd9\xd8\x88v\xfd\tm\xfa\xa4\xa7\x11\x97\xb7m\xe8<\xe3\xc3\xea\x1d\xfa\xb0\xd6I#\x03\x8d\xef-\xed\xfbo\x8a~\xa5\x86y\xee\x07\xda\xe02\xa5Cv9&\xd5\xc7\xcd\xd5%\xb7^>\xf7"=\xff\xdd\x1cU\xf64\xd7\x8f\x0e-\xbbh\xfcG\x98\xc7T\xb9\xeb?\xea\x89\n\x9bZHQ\xaen\xb1\xf2\xf4\xa6\xfaq\xa8\x9f\xde\x9a"U\xe5E\x18\xb5\x1aU\xe5\xd4\xe9\xfcPxih\xc7\xb9\xc3$IW`\x98\xcd\xc7\xdc\x89{eY\x9f\xa2>y\xdb\xc1\xaa\x8b\xbb\xbd\x8d\xa9f.E\x0bS\xcd\xd3\xcc \xc4\x14\xd2\nw^X/)\x1a:o_\x07\xb9\x97\xfc\xd2):\xf4X\xa9&\xc3\x8a4:\xf1\x9c"*\x85\xafED\x96\x15\x8b\xd9\x94\xb0\xbe8>\'M\x9b\x95\x1a\x1d\x92\xe9\x14G\xae\xafB%\xd9\xf6\xa2\xf2\xa3\xdbv\xab\x0b\x05\xbaJo\xc8g\xe4;t}\xa9>iN\xd2g\xfc\x88S\xd6:m#*\x9f\xad\xb6\xafV\xd0\xe9GZ\xcf\xb0\xa6\xa4\x0f\x1d\xa4\x0ey\x1d\x88\xd5\xd7R\x94\xf2\xc8N\\}\xf4#\xc5\x91\xaeT\xe2\xd5\xb5C\xeb\xbbh:\x8e\xd0 W\xackj\xc2\xa3\xde\x02\x0bK\xaf\xb7T\xd8z\xba\xb5\xc23\x97\xdc\t\x1e\xa3\x1c\xe4\xf4f\xe5\xb6\xff\x82\x0f\x87\xb9*\x1a\xfcP\xaf\xbc\x11\x8c\xa8\x0cJ\xef\xd3\xa8\x0c\xfd8w\x94$\xe9J\x9a\x17\xab.\xb8\x83\x9f9\xd2(\xaf\x9e\xa34\x94\xf6\xd4e\xbb\xf0M\xa7\x98\xfe\xd6\xb8=\xbcM\xd9\xa6J;H\xa7s\xbd,"\x01\xd3\xd3\xa8|\x0bK\xb5Ti\x8a\xbb#{\xc2u\xdd\xd3\xcb\xe1W\xd6\xa2E\xc7*/\xcd\xb6\xdb\xe7^C\x11\x9d<\x1d8UW\xf0Ks\x9c\xf7\x86\x12\xa3\xacu\xdbFX>u\xe3\xd8\x0e\xa2\xda\x86@\xe7\x19\xa6&\x04>\xd5\xc8\xa3?<\xa3\x98Z\xa4j\xdf\xab\xcde\x1bG\x1f\x03\xe8\xe06\x9a\xae>N\xb4\xd8\xfac\xf9\xd9\x12\xa2\x93\x94n-\xd3@\x8f]\x99\xab\x15n\xa4\x83\x97\xacs\x97\x87IX\xd8\x9c\xb1\xc1FK\xb5\xe9\xd8\xc7\x16SM|\xcd\xe7\xf6-\x1b\x9eB]]\xe4Z\x18\xa5lJ\x14J4\xd1\x95\x11?N/\xc2r\x19\xf3\x06L\xcbO\x89\xf7\x99\xbe\xdc%:\xed\xcd\xb7\x8b$\xe9\n\x0f\xb3\xc9\xf5 \x1a\x9d\xefk\xad\xba\xe0c\xeaBS\xb8t\x8d-\xb9\x1e\xbb\x1cu\xf2\x1aM@:\xa5\xd5s(h\xb2\xd5\xd3\xcdV\xe6\xc7\xdc9X\xdc\\\x99\x88(\xab\xeam\xba\xbc"\xc4\xcc\xbf\xcc\x85%;\xc5b\xd7 \xbc\x93[\xc4h\xbbMm0\xb0}+\x04\xa59\xc6{C\xeb*NY\x8bv\x11\xda6\xe4yX>#\xe3hg\xfbR\xd1\xe9G\xba}\xed1\xd5\xaal\x95\xb3\x11\xdeDU,\xaar\x1c\x924\xc75\xa3\x0cv*\xda\xfa\xb8\r\xb4n\xc1\x0b\xc4\xc8,\x16\x18\x9c\x91\xbb:\xc0\x99\xb1\xbfj\x05k\nE\x03t&\xa0\xe0\xdc\x88iO\xf4h\x1b\x1c\xe7>\xea\xe5\xd6_\xbd{O\x19)\xed8\xbdX\x95\xe9L;\xf9\xf0s\x07\xb9\x9ea\xebh\xa5\x14\xbe%-^^m\xc2\xc3\xd8i\xef\xeb\r\x9b\x06:\xee\x1b\xf7\xa1Ze:y\x8d"I\xde\xc2\xd0\x8d\xaf*\x84\xc4\x85\xf0\xddz\xdd\x06\x1a\xe2\xbe\x834\xa7Y\x9fv\xd4U\x83\xe8\xb6\x11\xcd\xce\xb4/\x15\x9d\xb6\xd1\x96\xf6\xe8\xdaE\x13Q.\xdb\xa4\x8f:\xb4G\xe0\xc5\x94q0E\x0b\x8b,\x8e<:Q\x90\xcf*\x95\xe2\xc1\xd9g\x8a\xe6\xe7\xbf\xaa\xdd\xb1\xa7P\xea\x14/\x149\xda\x86\xb5\x8f\x888;\xb2o\xc8\xedNb\xbb\xa28>\xa1Z\xa2m\x9e\x1e,\xeb(\x84\xd8ye\xa2\xc2l\xde\xa3\xbbU\x9e\x06\x065\xa4\xa0\xbah7a\xe9tY|>\xac\xae\xd1J\x92v\x91~\x95\xce\x9d\x17\xbe\xcf\x82\xdb\x87o\xc5\xc7\xa2s\xae\x11\xd6r\xeb\xe9\x10\xa3\xed6\x89t\x80\x7f\xd6EP\x9ac\xbc7\x948e\x1d\xf4N\x0f\xa1\xf9\xd4\x8c\xa3\xad\xe8\xb4\x8dX}m\x1f\xa5\xd2!e\xa6\x8d\xa6>n\x03m\x12xF\x88\xd8\xcam\xbaz7E\x83A\xa3\x99\xe5\x8f"\xb6f\xd5\x85\x16{\xba\xe4\xf5_UW\xb8 \x86\xde\xf0\xf1\x17\xfa\xb3Y\xbeM+~>0\x85\xe88\xb9"\xce5F\xe5\x99\x99\xb7i@\xb7\x03\x85\xe1t\x9e\x80\xf7\xc6\xcd\xab <\x8c3\x05=\xea\xef\x9e\x11\x04\xd5\xc5\xb5\xd6~X\xe1%<\x9d\x07i\x80-6\xff\xd9\r[\xdb\xa5\n[x\xee\xb0\xdae\xc5\xf9k\x12L\xaf\xe8X~X\xcd\xde\x1b\xa3\xed\xd2\xca\xc7\xca\x0f\\\x02\x9e\xf1\xc3/\xcdq\xde\x1bJ\x8c\xb2\xd6m\x1ba\xf9\xd4\x8d\xa3\x8d\xe8\xb4\x8d\xb8}M,p\xb62\xab\xaa\xa3\xa3\x8fA\xf0\x08S\xd5Y[\xf4\xa1->x\x1b\xd1\x808\x03\x14"*\x8c\xd8\xa9p>\xf5\xbee%;X\xd34o\xa6y\n\xa47\x85\xe2Fs\xb9@\x0bl\xad\xe6f"V\xa5\xb5\xe3l\x1d?\x1f\xbc(\x17\xdf\xc6\x9d$]\x81a\x9c\xf2\xe0\xd3\xaa\x8f\x7f\xb3\xc4\xe5.\xfd\xbc\xd6\x0f)\xe8\x02\x95\xc6\xb8\xd1KD]d\xe5y[\x88\xc8[G\xf6m\x9aI}Jc\xaa\xafV\x9e\x8b\xb44M}\xe3\x94\x95\x10\xcc\\\x8d\xc6J\\\x0ewyJ\xcd\x96\xfb\x99\xa1\nMq\x19\xac\x88\xef9\xae\xf3\xb9^\xbe\xb6\x9e\x8eD\xb7\xed\xa6\x87NQ\xea\x16\xcf\x00\x9dx\xfb<?\x92\t\xc3\'\xcd\xda}&\x828e\xad\xd36\xa2\xf2\xd9\xb6\xf6\xc5\x03\xc9\x98Ua\x1e8\xed5u\xcdB\xa7m\xc4i?L\x87\x10\xf8\x8a\x10\xf8xe\xdd\x8c\x9e>\xfaa\xf9\xec{O\xc8\xab\x98l\x01\xc3\xd8\xdcZ|\xef\xb7[\x1fU\xe4\xa5\x87\xcaG\xc1\xdf=y\xbe\xd9\xfa\xe8\x9d?l-\xd6\xe4\xe5\xae\xc3.\xfb\xf7\x167\xe5\xf5\xd3L+e\xfdt\xe4sg\xda\xb2\xc8\xeb\x13l\x93\xb5\xbfo\xbd\xf7\xce_\xb7\x92f\xb3}.\x1a\x00\x000\x8e\x86\xff\xfcI \xfe\xce \xed\xda"\x1b\x0f\x08\xbcq\xd8\xeb\x08A[2\xc5\xb49\xe8;\x00v\x13;\xd6\x96{NP\x8e\xe2\xff\xb0\xacU\xc4\x0f\xc5Jt\xaa\xa5<B\xe0\x01\x00 \x021\x98\xec\xf4\x7fD\xb5\xe3\x9d{\x84\x9fF\x9e\x03\x00\x000\x08X\xf0\x00\x00`(\x10x\x00\x000\x14\x08<\x00\x00\x18\n\x04\x1e\x00\x00\x0c\x05\x02\x0f\x00\x00\x86\x02\x81\x07\x00\x00#!\xfa?$\x06b\xa9\xact;S\x00\x00\x00\x00IEND\xaeB`\x82'
    __img_2 = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00N\x00\x00\x00\x14\x08\x06\x00\x00\x00#\xbf\x0b\x8c\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x01\xeeIDATXG\xed\x98\xcfK\x02A\x14\xc7_iR"\n\x1d\n\xff\x83.A\xec\xfe\x07R\x0b{\r:\xf9/\xec\xa5\x14:x\xf6 $]\xfc\x03\x02\xf1$t\x95D\xfa\x0f\x14\xc9\xb3g)HX\x11\tSj\xe7\x87\xbb\xb3\xba\xb8\xce\xe4t\x90\xf9\xc0c\xdf\xbea\xbf\xce\xbe}\xf3fp/y\xf7\xf9\x03\nn\xf6\xe9U\xc1\x89J\x9c \xa1\x89\xd3\xcd\x14\xd8\xe5clu\x8d\x06Y\xb4\x84;\xde1\xa34\xb8\xfb\xa8\x8a\x13D%N\x10\x958AB\x8f#\xa8\xc7\xbd^F\xb0\xdf\xac\r\xe1\xa6\x83]\x0f\xd4\xe3\xb21\xec\xf6[#\xd0\x1a3\xec\xb3\xcf\xb1\xf85\xa2P\xbcO\x82u\x82\xfc)X\xb91Tq<\x06\xf5r\x02\x0c\xe4~|A\xa64\x81\xb6\xe3\x86k\xb2z\x01`\xad)\\\x07\xfe&\x1f\\\x15gd\xc9&\xe03\x9a\xb4MA\x1a\x81\x9b\xcc\x1f\x90\xa1\x19\x86\xb4\xa5\xdan\xd8\x90\xca\r\x19\x1bA\xe5\x83\x8c\x19Wq\xd0\x89\xcbE\xb8\xe6\x0c\n%:V\x9b\x92\x01\x07T\x918F+w\x1bp%\xce\x9d\x00k\xcc\x04\x83\xf0\x8e3k\x96\x10\'\xdb\xd3\x8cA\x85]=\x8emZ\xb9\x92*\x0e\xf5\x1a2\x91\xa0\x9e\x14L\x04\xce\xd2\xc4\xd3\xcd#\xd2\xdf|\x88h\xf2cdSP\xa4\xf3X\x87\x9c\xc4i\x87^%\xf4\xc6nuZ=\x1as\x99\xc1\xf3\xdb\x9c\xfa\x11\xb0\xf2k\x12\xb3\xb1&\x0fhs :\x99\x967\x0f\xf3"\xfc /%q\xfa\xe9\xe2\xc5\xe7Py\xa1K9\x1d\x87\xdbs\xe2\xb2\xa0\xbe\xe5\x7fy\xe7\x99\x8714\xe9\xdd\x02\x1e\xcd\xff@J\xe2\xda\xddo\xe8c\xcf\xab";\x7f\xe0\x1c\x07pp\x85\xea\x13\xed\x97\xd8l(\x0c\xe8\x00\x03\xaf\xe6fx=\xce\xab\xf294\xba\xe4H\xb5\x0e9Ku0\x01mi\xd3h\xd6lx|\xa77"\xc8\xd0\\\x01U{\xf0\x87[F\xfd\x1f\'\x88\xa4]u\xf7Q\x89\x13D%N\x08\x80_\xdd\xd4\xe7\xb8m,\xcb\xb5\x00\x00\x00\x00IEND\xaeB`\x82'
    __img_3 = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x1f\x00\x00\x00\x1f\x08\x06\x00\x00\x00\x1f\xae\x169\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x01\xaeIDATXG\xed\x97\xbd\xae\x01A\x14\xc7\xff\x8b\xb0\xd1jD#\n4\xe2#\x88N\xa3\xf4\x06^B\xed\t\xd4\xdeb\x1f@-\xa1#$\xbe*$\xa2\xd3h\x05\xf1q3\xe3\xdc\xc9\xce^\x8c+7\x99\x9b\xf0k\xf6\x7fNf\xe7\xbf{293c\x84B\xa1\x0b4\xe1\xa2\xa7\x16\xa4?\x0f\x04\x02(\x14\n\xf0\xfb\xfd\x94\x919\x9dN\x18\x0e\x87X.\x97\x94\xb9\x12\x89D\x90N\xa7\xe1v\xbb)#\xb3\xddn\xd1\xedv\xb1\xd9l(sE\x983\xe3Z\xad\x06\x97K]\x0c\xcb\xb2\xd0\xeb\xf5\xb8\xce\xe5r\xa8T*\\?\xe2|>\xa3^\xafK\x1f \x9c\x92\xc9\xe4S\xc6\x8cT*E\n\xc8d2\xa4\x1e\xc3\xe6f\x1ev\x84\x9b\xc7\xe3!\xa5\xc6>\xf6\xd5\xf7\x18Z\x17\xdc\xc7\\\x0b\xefc~\xb9\xc8\x9d\\\x98/\x16\x0bRj\xecc\xe7\xf39)5N\x0f\xa9\xbd\xb2\xd6\x9a\xcdf\xe1\xf3\xf9(\xf3\x93\xe9t\x8av\xbb\x8d\xc3\xe1\xc0c\xaf\xd7\x8bb\xb1\x88D"\x01\xc30x\xce\xc9n\xb7\xc3`0\x10]\xf1\x9b\xcf\xae\xc6\xc9\xe7\xf3|\xa30M\x9322l\xc1\xb0\xb2w:\x9d_\x95}\xbf\xdf\xa3\xdf\xef\xdf/{8\x1cF\xb5Z\xe5I\x15\xcdf\x13\xadV\x8b\xebR\xa9\x84r\xb9\xcc\xb5\x8aF\xa3\x81\xd5jE\x91\xad\xec\xd1h\x94\x94\x9ax<N\n\x88\xc5b\xa4\xd48=\x84\xf9\xbd\x92\xfd%N\x0f\xad\x0b\xeec\xae\x85\xffa~<\x1eI\xa9\xb1\x8f}\xf5=\x860\x9fL&\xfcx\xfb\x0c\xa3\xd1\x88\x94\xac\x1f\xc1\xe6\x1e\x8f\xc7\x14]\x91\xda+;\xbb\xab\x9a\xc6z\xbd\xbeyi\x08\x06\x83\x14\xddf6\x9b\xdd\xbf4\xe8\xe0]W;\xf0\x05~\x1e\x99\t.w\xdc\x9d\x00\x00\x00\x00IEND\xaeB`\x82~\x85\x97/_r\x88t\x109\x81%\x93I\xb8w\xef\x9ez\xb6\x98\'O\x9e\xc0\xd3\xa7OE\xf9\xe6\xcd\x9bp\xfb\xf6mQ\x0e\xe2\xe1\xc3\x870\x1c\x0e\xd5\xb3h\x13\xb9\x10y\xfe\xfcyU\n\xe6\xe2\xc5\x8b\xaa\x04p\xe1\xc2\x05U\n&\xcc1\xfeu"\'\xb0y\xe1m\x95\xfc\x89c\xfc_\xe0$\x9f\xd1\n\x0b\x8c\xd1\n\x0b\x8c\xd1\n\x0b\x8c\xd1\n\x0b\x8c\xd1J\xe4\x04\xf6\xfd\xfbwU\n\xc6\xd9\xf7W\xc7E\x9d\xc8\t\xec\xf5\xeb\xd7\xe2\xabe\xcb\xf0\xea\xd5+Ur\x97\x17As\x0f\x06\x03\xf5\x8c\x89\xe4[E\xf4\xdd\xc8\xa0\x17N?~\xfc\xe8\xfb\xc5\xdbs\xe7\xce\xa9g\xfe\xbc}\xfb\x96\xbf\x13\xe9\x80?M\xc1h\x85\x93|F+,0F+,0F+,0F+,0F+,0F+,0F+,0F+,0F+,0F+\xbf\xf4V\xd1x\x9c\x80\x8d\xc2-\xc8\x99&\xc4\xe3\xaa\xd2\xb2\xa0\xdb\xaaAg\xc4\x9fGg\xa6\x84\xf6`$\xaeB\xad\x02\xc5,\x8a\x0b,\xf1\xc9\x01\xf1\xc0\xb6\xb8!\xfb0\x8cMh\x0f\x96)=\x82\xa2\x89\x0e\xab[\x87\xad\xceH\xd52\x8c?\xa1\x046\x1eg\xa0\xdc(\x829h\xc3\xddfO\xd5\xce2\t\xa1\xc2\xcb!\xd6\x00\xc3g\xc3\x15>\x13\xf9\x12l\xda\xed\xc8\xa0]\x87fO\n\xd6\xaf\xad\xb1\x0f\xc2sf\xa1\x0b\xf5\xda6\x8cb\xb1\xe9z\xd0\x7f\xb6\xcb\r\xe8\x89:\xcf\xb1\xd1\xcbZ\x83]h\xe1\x04r\x8c\xf4\xc0\xeey\xdcuCH.\xd1gC\x1e\xdb\x9a\xf6q"7\xe2\x82u\xf9\xd8\xc4\x86\xce\xabP\xcbAv\x9a\x7f\xa0\rZS\xfbd\xd0>9\x9cg\xd2\x8c\xc7\xa9\xc9\xe3\xd8$\xf2U\xa8d\xed\x0e\x84\\\xcb~\xc8u\xff.\xe1B\xe4F\n/&.\xf5\x00\xaf\xf6\x026\xca\x14B1\x80\xa20\xea\xf56^\x12\x13\xb2\x95\x1a\xe4\x13R\xcb\xf2\xe4\xc9\r\xa2\x91\xdbmhw1\xc0\xae\x89\xa6\x85m^6\xca$.7\xf2\xd8X;\xe8B\x1b\xc7\xd3\xf0\xb8Y\x84JyC\xf5\xf8;\x04\xd9\xc4Er\r\xe2$\x9a\xba\xec;\xb0\xe2`\x167\'}\x8d\x14\xce\x83\x9b\\\xb4\xb7\x07`\xc5M(\xd6\n\x90\x98\xf9]29\x07v\xf9k\x84\x12Xr\xcd\xb9#\xfc\x19\'\xf2\x98\xfc\xa3>\xbar\xc7\x8dF=\xd8nuq\x0f\xa2\x91\xd2I\xd1\xbeI;\x0b\r\xb4\xb5\xd5\x84N\xaf\x07\xbdN\x13\x9a\x18n\x17\xb5y\x19\xe3..\x9a\x94\x03Z\xaafzl1\xbe\xd9\x81\x1e\x8e\xef4\xb7\xa4\x81\xcd\x9c\xff\xc5\xfc\x03\x04\xd9\xc4Kl\xd4\x81&\xad\x7f4\x82\xe1\xf0\x90\xee\x9f\x10\x0b\x8e\xd4\xaf\x11\xf4\xf0\x9c\x9a\x1d\xb4\r\xb6\x8fzM\xd8\xa5\xf3Cw\xe6L\x81\rro8\xf0\xf0/\xff\x84A\xa8\x1ft\x1f\x1e\xd1\x99\x06\x88\xcc\x88\xcb\x1e\xd9\n<\xca\x8a\x9a\t\xc2N\xaa]zA\x8f\x0b^\xd4\xe6\x02\xdd<%\x82(\xa4\x1d+7\xf5bs\xc6\x1f\x8a+\x84mt\x05l{\xc7\xb3Pi\xf8-\xd0A\xe8>\x14\xcaj("\xff\xf3\x9ak\x13\x1fH\x94\xb5JV\x8e#o^\x9f\x86\xacq\x02\xc3m\x9a\xee\xe2\xb1\x15\x85$\xfa8\xa0p,|\x81u$B\xa0\xef\xbd\xd72\xeb^\x01\xe1\xfec\xc0!\xe63\xf8\xc7La\xb8A\xef\xb0\x08\xca\x9bv\x0e\xd5\x13\x1b\xdaM+\x88TF\x81D\x85\xee_$f9U\x1b\x12\xccA\xda\xad>\xc8%\x1a\x90\xde,b~\xe5!T\x1f\xd5^,Cf\xbf\xa1\x1a\xdd\xcc\xb5\x89O\xaeC^\xacU\xefc\xc9\x80[4/\x86SL\x9a`\x1b\nRx$\xba\xdd]\xe8\x1f\xe2\x91oa\xf8\x9d\xec2\xc2\x10\xf9\x995\xf0\x1e\xccA\x88u\xff\x0e\xe1r\xb0a\x1f\xf3\x01\xfc\x8b9M)\x93\x90u^&"40\x14P8p<\xc8\x90N\x91zY\xd4f\x83;O\xe42\xdd\x9d\xd9$t\xcex\x11.P\x90\xde\xd4\x91\xc2\x07\xad\x8b\xc2\xd0<\x96\xef\xd3\x83\xbe0N\x1c\xd6\xbcQ/\xc8&s\x90}z\xd0\x901Pz`\xdbK\xef\xe2\r\x02nr\xd2\xe7L\xe6\xa2re\xcb\x8e\xa9s\x08\\\xf7\n\x08%\xb0Xl\xa4r\x074V\x11\xdd}\xb5\x04\xa5\x92zT\xab(:\xccq\x1c"\xac\x96\xf2\x90\xc9d\xf0\x91\xc7v,c\x12J;S\xd8\xcb\xd9\x8ew\x8d\xa5|ba\x9b\x0b\xdc}\xad\xedY\xe3\xf9\x8d\xcf\x97\xaa\xeae\x15\x1fA\xae\x08#\x99\x84D"\x03i\nYh\x9d\x99\xeb\x1a`\x13/\x94_VK\x19\x9c3!\xe6-\x8b\xc4\x12E\xea\xd0\xb8\x99*\x88y\n\xe5M\xbc\xdbT\x95\xc8\x18\xfb\x17d\xc2\x07;\x9e\r\xe5%p\xdd+ \x9c\x07C\xe8"\xd6\xe8.\x88,\x86w/\xf4\x8f\x9f\xe8A/\xba\x1e\xa0\x01\x84\x08ku\xd1\x1e7\xd1\xdb\x14\x8b\xf8\xc0v\xcc\x07l\xfb\xec7\xe8\xce\x06\xc7\xdb\xedd\xa1\xa3\xe06\t\xbdc0{{m\xe3\x1d/o(5\xbefG\x1e\xb5R\x81J\x05\x8f\x15\xa7\\f\xf6\xf6~\x19\x9b\xb8@\x8fGb\xac\xa8y)\x1d\xe8bx\xa4\x974b\x98\xd4O\xcf/\x87s\xb4\xe4M\x8c \t\x05\x11\xc6\xb1\xff\x02\x1b\t\x96X\xf7*\xe0o\x151Z\t\xed\xc1\x18&\x0c,0F+,0F+,0F+,0F+,0F+,0F+,0F#\x00\xff\x01\xbbNt)P\x99\xa1*\x00\x00\x00\x00IEND\xaeB`\x82'
    __img_4 = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x94\x00\x00\x00\r\x08\x06\x00\x00\x00OUG_\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x03\xb6IDATXG\xed\x99\xb1N\xe3@\x10\x86\xff\xbb\x17\xe1|QD\n\x17\xc7\x13 B\xa4K\x91\x10$WtH\xc8\x12TI\x15\xb9\xa2\xa0\xb2\xa8\x92\xea$,$:*K\xa0\xa4\xe0$\x13\xc4\x13\\\xe3\x02\x14\x85\xc0\x93p\xe3\xf5\xda\xdeu\x1c\xdb\x89}W\xe5\x93V\x89=\xeb\x99\xd9\xf5\xec\xccn\xf2\xe5\x93\x80\xc0\xdc:Bc\xfc\x13\xce\xfd1\x14~/`\xd2\xdf\x81\x8e\x01f\x97\xbb\xfc\xce\x86\r2_\xf9\xe7\x86\r\xa5\xb0\t\xa8\r\xa5R,\xa0\xe67\xe8TvP\t\xdb9&\\\x04<\xa3/\xc9v\xd0\xb1>\xb8\xcc/\x9f\xe2\xb5\x87Wn+\x9d\x1b\xcc\xf9u\xba\xfe\x0fX\x9db:<\x1f\xa2\xfbQ\x0bt&\xf9\xb8\x1c\xdf\x9f\xb8\xae~\xe8p\xe4/\xf31\xec\x13\xf3\xa7\xff\xcc\xaf"\xa21\xe5\x1bs\xd6\xdcf\xdbI\xee#\xfb\x9d\xac\xa3P@\xcd\x9d7\xb4\x9c?\x98\xcd\xfcfi#\xe8\x81\x919\xb9e\xdc\x85\xb2\x99\xd5\x86k^\x0b\x01\x91M\xaa\xfe\x9c\xa4\xe9\xa8_\xf2\xfbN\x17*j0x\xbf{}\x8b\xc9\xd7A\x8d\x8d\xd9\xd6\xc5E\x00\x9a\x83C\xf4`\x86}\x98?\xfc%\xd6\x9bm\xc0~\x8c\xcd\xd13~\x99/\xd0\xba\x8b{\xdauY\xc7\x8e\x17L\r\xb3\n+\x18\xdb\xec\x0e\xc6ko!\xa8\x92\x03\xca\x1d\xa2!F"o\xba\xcd\xe5\x1cE\xbf\x80.X\x97\x1cU\x8eqY\xe0\xc5x\xa4\xea\xcfI\x19:\xd6e>\x9bR\x84}\x97_\x906\x90\x02\xb6~F\xc1\xec\xfe\x86\xc3"\xea\x04\x86:\xc2P\xcc.\x93G\xd8j\x17gu~]\x06+\xdb\xe1\xc1f] \x12oA\xef.\xceer@\x91b\'\x8c\xc4\xa8Y\x1a\x97\x0bHiP\x1f\xf1\xbb\x01~\x8af\xb2\x87}\xd2!:\xe4\xaf\xd6\xf0Yj\rr:N\xba\xfe|\x14\xd1\x11\xf71\xab\x04\x8a\xfd\x93N\xcbj\xf5\x1b\xff\xc6Q\x14l\xe3\x05S/\xa0\xe8%5Z5\xb8\xe3\xa7\xa8|=\x8c\xa0\xb6\xf6V\xceN\xe9s\x9b\xd3\x8eM\x19\x88=\xdf\x83M\x19\xbc\x1aw\xa2\xbe\x0f\rS\xcc\x02%D\x81\x92\xe7\xef\x91\xd8\xa4\x05AG)^\x86\xa2\xf8\x9e\xcb\x9a\x8f\xe4\xd8\x11,\xc1\xb8T\x1e\xa89F\x8dK<\xb2\xf4/N\x8a\x17\xc0\xceX\x9c\xb8<>\xa6#\xf9H\xa5\x11\xa6!\x8d!\x8e\xd4\xbf\xfbF\x99^\x1es\x16\x8a~\n-\xc8X\xe4\xff\x83]C\xab\x11d\xb4<c\xf6I\x9f\xdb,;\x1c\xca\xa6\xecy\xb6%\xc8\xc7\xfa\x01\xe5\xa5H\xb4a\t+\x90\xa5\xf8e\xb04\x1b\xac\xc4\x1c\xe4\xd0\xaf\xe8&\x0c\x88\xe5\xd9\xc0t[\x98\xb8U}\xccB\xca&9`+X\xee\xefN\xdf\xf97\x0e\xed5_\xa5\xd5\xbf\x8b\xa6\xf6\x82\xb1C\x99\xd0\xf3_;\x95Jv\xe6\x98s\x93nGB\xd9C+\xe9\xdd\xb1\xf9\xad\xa2"<\xb7~@)\xdf)jGx\x08\n(\x9d\xa6zbZ\x9d\x9c\x0b\'\x1cbr\r\xd3MH\x9b\xcb\xc8\xd2\xcf\x102 k\xb78\xabr\x91G.\x1d+\xb0\xf0\xf23`\x13\x1e\xebOeD:\xf9\xf5\x86pc/\xd3\xdb\xe7\xb9\xe3k\xf4\x87#h\xcd\xf8\x8f\xc8\x19c^\x81t;"~f\x94\x0f\x18\xe4;=\xa7\x1a\'\xd26\xa6@@\x1dc@i\xd4\xd6\xf9J\xe9\x01\x83X9\te^\xd3\xa7t\x8a\xba]\xbe\n\xe2\xe4\xd0\x9fI\t:\xa4\xbdHcH\'W3u\x0cR\x7f\xda\xafi\x96<f\xd5\x18\xa0:\xe4\xf2\xca!\xcc\xed\x84\x7f\x1e\xbclN\x0b\xc1F\xc9\x9b\xf18+\xd8Q\xf4[*\x9bS\xe8\xc1\xd8\xc8\xf7q\xebn\xf1D\xec\xfd\xf5\xb2\xe1\x7f\xf0\xfeyu\xf0\xe3\xf3\xe0\xea\x9d_\xa7\xb1J\xdf"\x94o\xa7\xc0\xa6|\xc3?c\xfe\x84\xb1\xdbF\xb7\xe0\xcf.\x99\x94n\x07\xf8\x0b^K\xda\x1d\xe3\xfbM\xa6\x00\x00\x00\x00IEND\xaeB`\x82\x1f\xech\xe5\xc7\xd7\x85g\xd6\xfb\xecF\xdc\xb8\x8d\xb4\xe9aD\xfb\x17\xf3}\x18M\x99\x1e\xc8K\x9f\x1b8\x8f\xad\xdbs\x14\xc2\xfb\xc9\xfa24=\\\x02\x0b\xa5\xb3\xf3[tt|-\x8f\xa2\x04\x85\xea\xd2\xe1H\xb2\x159\xe4\xaaq\x159\xcb\x8a)C\x8d\x83\x90\xee\xde\\9=\xe0\xc1~\xdc\xc8"\x03k\x98\x98A\xb9\xd72!\xfc\xb6\xd1\rm\xf5\xf7\x80\\q\xf5\xf2\xa5rU\xfd\xa7\x10{\xb9Um\xb5\xbe\x88\x91\xf4\n\x16\n\xc2sQ\xfb\xd3\xb7\xb5\xd0\xd1\xb5\xcf\x9eq~\x8eF\xfc\x12F\xf7\xfb\xec\xe4\xf8\xf6\xa0\xfb\xa0z>\x08,\x14:*?<\x9cD\xb5\xba!\xcfn\xf9\x85\xeaP\xdd\xe1\xe1K\x87s\xec>\xde%V\x99y,\x9a\x01je\x16\x13V\xf7^\xbcky\xe3#(\xce [\xda\xc7}\x1f\x84\x9b}\x89\xc5c\xc94\x87;=*\x8b\xf0d\xc3\x07{&\xb5\x0br"\xd9\xca\x8bpF{\x1361\x8d\x92m\x92\xd2>\xaa\xb40\x83\xc9\xe9y\xa4G\xec_8\xbb\xf4\xd9\x07\xce\xcf\xb1\xd2\xf0d\xfa\x8b\t\xd1vQ/\x91\xb9\xa5\x85\xd3A\t,\x14\xe2\xc4\x89\x0e\x0c\r\xfd =\x83\x1f\xb1\x98\x87"\xa9.\xd98\x14\xc4f}J\xb8\xf3\xbc\xa1V\xb6\t`\xca\x16\xd64\xf3(\x19ed\ns\x07\xafZv<\xd8w%\x02\x1bZ\xac\x9f\x9a\x062Y\xc7>h\xe5\xc5~(\x9d\xd3\xfb\x9c\xc8L\xa1gZ\xe5w_G\xb6W\x847\xf7m\x93\x94\xbc\xaf\x10x\x1e\x11o\xe2\xed\xf8xN\xdc\x98\x13\xe1[\x19\x86\xd97\xd1\xf6\x85\xd1\x87\xa1\xde\x10Z9\x16\xc51\xfb7o\xde\xe1\xd5+:f\xdf)\x8f\xa5\x1c\xf4m=\xedIH \xe4I\x06\x07/``\xa0\x9f\x8f\xd9\xb7\x0cb\x05\x1e\xf3:\xb9\xfc\x94\r\xc3\x97z\x8e;\xa1\x85bB\xa7\x80\x9f<yn\xf9\xe1V\xac\xf96\x8b\x7f\xb8u\x14\xf01)\xe9K\xd2\xd4:\xc6mo\t#\xe7K=\xc7\x03\x91\t\x85h\xfc\x14xC\n\x82\x84a\xbe>&\xc1P\xe2\x9f\x02\xb72^\x85\xf2\xff\xf3&\x12\x12\n\xc3\xd4\xeb\xd5\xfa\x83k\xe7\xea\xd7\x1eT\xd5\xf5^\xd6\x1f\xfcT\xef\xea:W\xef\xfa\xf9Wu\xe7p\xf8R\xcf\xf1C\xa4\x1e\x85a\xfe\xab\xf0N\x9aa<\xc0Ba\x18\x0f\xb0P\x18\xc6\x15\xe0_\xc0\x90\xcc\xcc\xee\x1a\xd8\xed\x00\x00\x00\x00IEND\xaeB`\x82'
    __img_5 = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x009\x00\x00\x00\x16\x08\x06\x00\x00\x00z\xe24f\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x01%IDATXG\xed\x98!k\x85P\x18\x86\xdfM,\x16\x9b\xc1\xa0\x8c%a\xc5_0X\x1f\x0b\xc3\xbebRXrq?\xe0v\xd35\x0c\x93M\xc6\x10\x0cc\xb2h\xba\xc1|]\x13\xec\x06M\xdb\xf5x\xb6\xbb\xa5\xe1\xca\xee\xf9\xf0\x81\xc3\xf9\xde\x8fS\x1e>8p\xce\xd1\xfb\x0e\x10\xe7\x98\xef\xa4!#YU\x15\xd24\xe5\xe9\'$$\x9b\xa6A\x14E\xc8\xf3\x1ceY\xf2\xee\x1e\xe1%\xbb\xaeC\x18\x86\xe8\xfb\x9e\xe58\x8eQ\xd75\xab?\xf9\xbb\xe4\xcb=N\xaf\x1e\xf0\xc6\xe3\x7f1NOQ\x14\x18\x86\xc1\x96\xae\xeb\xc8\xb2\x0c\xc30\xf0\x13\xc0\xfc\xdbu\x94s\x9f\xa6\xfa\xec\x16\xcf\x8f78\x99\xd2\xc12s\x92\xaf\xb8\xdb\t^\xaf7\xd8\xae/y\xef\xf0\x99)y\x8e\xd5v\x83\xd5\x05\x8f\x82@\xe2v\xfd\x8dE\x92\n\x8b$\x15\x16I*\x08\xff\x9eL\x92\x04EQ\xf04a\x9a&\x82 \x80,\xcb,\x0b?I\xc7q`Y\x16O\x80\xaa\xaa\xf0<\xefKpDxII\x92\xe0\xba.4Mcb\xbe\xef3\xd1\xef\x90\xf9\xfeh\xdb\x96\xbd+m\xdb\xe6\x9d=\xcb\x1f\x0f\r\x80\x0ft\x91Y(\xabM\xb3m\x00\x00\x00\x00IEND\xaeB`\x82E\xfcS\x92\xe00\x12\x1cF\x82\xc3Hl7L\xe8\x0e\x9d\xc7+\x1c\xd1tW*\x95\n\xe2\xf1\xf8\xdc\x91N\xa71\x99L\xe8\x8c\xd5\x94\xfc\xc6D"\x11\xf8\xfd~\x9a\x01v\xbb\x1d\x89D\x02f\xb3\x99VVS2\x8c\xc9dB,\x16\x83\xd3\xe9\x141\x92\xc9\xa4\x88\xa3\x87\xb2{\x8c\xcdf\x13A\xa2\xd1\xa8\xf8\x87\xad\x97\xd2\x9b\xaf\xf6((\x10\x08\xd0L\x1f\xa5\xc3l\x82\xc3Hp\x18\x89\xbd\x7fD\xebp8h\xa4\xdft:E>\x9f_\xfd\xec\xda\xa8~\r\xd3h4\xc4\x82\x11\x05\x83A\x1a}\xfb\n\xc3\xe6\xf1\xe6+\xc1a$8\xccR\xc0;Z.\x9c\xed\x8c\xbdu\x98\x00\x00\x00\x00IEND\xaeB`\x82'
    __img_6 = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00V\x00\x00\x00\x1b\x08\x06\x00\x00\x00\xe6\x90xE\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x02\xd8IDAThC\xed\x991k\xdb@\x14\xc7\xff\x8d\x8d0\xa9\xb1!C\x8ag\xcf)E\xfe\x06\xc1u\xf1\xd2!\xd0\xc9\x18\xfa\x01\xbc\xa4.\xa4\x909\xd0@C\x17\x7f\x80B\xf1\x94\xad\x8b\x89k\xf2\r\xa2\xa1^\xb2x65\xd4\xe0\xe0\x86"\xe2\xb6:\xdd\xd3\xdd\xd9\xb2,\xd9\x95\xda\x14\xee\x07"\xf7$\xebI\xf7\xd7{\xef\xde\x91\x07\xb9W\xdf~A\x13;[\xf4W\x133Z\xd8\x84\xd0\xc2&\x84\x166!\xb4\xb0\t\xa1\x85M\x88\xb5\xdb\xadR5\x8f\xcbr\x8a,I\xb7=\xc6\x0b\x8b\x0c\xcd\x1a\x11[\xd8\x86u\xb6\xb3TT\x8d\x9f\x88\xc2\x1a8\x7f\x9dA\x91\xacA\xef\x06\xf9\xe6X\x1c\xfb\xbd\x19]\xd1xD*\x05\xf5\x97;h\xed\xf11\x13\xd5\xec\xdcqC\x13H\x04a\x9dh=\xcb\xa2\xe2\x8em4\x9aS|t\xc7\xabP\xef\xf1X\xbc7\x8d\x93\xa3\x1c\x1a\xbbdz\x8c~`\xff\xf4\x16Wdr\x96\xf9\xe3\xa8\xb5=\xbc\xfe\x07<\xd3\xc3}\xb6\x8d\x03\xf1\x9b\xa8\xf3\xf5\x13^\nLCN\xa8o\x87?\xc4\xccb\xb2T\x04\x03-\xa7F\x9f\x9bd\x06\xb1\x9b\xc1\xe5\xd16Jd\xba\x14\xd2\xa2\x0cmB\xa5\x16\xe1\xb91\x13s\xbb\xe5DV\xcd\xa0\xf1\x0c\xadw^\x1d\x9e\xa2Kg+\xb5,\xea\xee\xe8\x0e\xc7\xa7\xb2N\xe7\x9b7h\x8d\xdc\x0b~\n[$,\xf7\x19T\xd3\xaf:\x13\xc5\xdf\xbc\xcf\xcaS\xf6\xb1\x94g\xb6m~\xc1\x81E\xb4{\xce\x97)\x9b\x13\xaf\xb0Jt\x0fz\xdfq<$\xc3I\xa9\xb7B\x0c\x03\xcfE\xf4\xb0\xd4\xdcq"\x9c\x1dJ\xfa-L\xb0\xf4\xc8K\xef\x19\xae\x85\xcf`XI\x98\xf7\xb9)<\xcb\xb8/~D\x8d\xfcpa\x87?1\xa0!\xf6\x0c\x8a\xb6$1pXM\xd3\x98\x91\xc6\xc1c\x12ve)\x92\x1f)\xc9\x96\xb0R\xcb\xe3\xa4@\xc6\n"\x08k\xa3#Rtq\xd2\x7f\x8aZ\x0ed\xda\x16\xcb\x0f\xe5\xcb\x17\x0cT)\xea\xba_d\xfa\xfa032:\xfbS\xf29F\xa3O\xe76\x82-^\xdc\x8f,?)T\x9f\x84k\x10\xa1\x148\x93\xff,\'T,\xe7`-\x88\xcbR\xcfM\x11\xcb\x16\xb5\xb4X\xce(\xd1m\xe0\x8d\x88"\x1b\x9f\xd6\xd8\xa1\xd5\x9fy\xfd\xf3\xea\xfb\xd4r\xd1\xba\xa0\xf7u65\x87\xd4&\xfem"oi\x83Z\x19\x0f\xd1\xd2\xb0\xae@,`~d\xeb\x13\xdcB\xf9\xdb\x9e\x10X\x84^\xa4a)\x9b\x18\xce\x0c\x83Q\nE\xe6c\xb1\x8dS\xdeSm\xd9B[2w\x01\x9d(\xeb\xc7r"/^|\xc5\x95\xab\xfb<J4Y,\r\x97\xfd\x8e\xa7\x95\x9c@\x00L\xa4MV\xe7\xe1-Le\xa5gt\xdb\x13\xbc\xffJF,D\x13\x95q\x8f\xff\xe7%#\'h\xb7\'\xb2\x88}\x8c\x0f+\xea\xef? \xdevK#\xd0\xc2&\xc4=.\x05\xff7:b\x13B\x0b\x9b\x10Z\xd8D\x00~\x03\xe2F1\xa6\xb8\xd9\xfc\x88\x00\x00\x00\x00IEND\xaeB`\x82'
    __img_7 = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00\x87\x00\x00\x00\x12\x08\x06\x00\x00\x00qL\xcd\xfa\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x03\xcfIDAThC\xed\x99KK\x1bQ\x14\x80O\x1bq \xa0"H\x13\xdc\x0e\x88\x14B!\xf9\x07\x92\xa6\xe0\xc2\x9d;\xb3p\xd1]6\x8a\xa0\xe0\xda\x85 v\x93]\x17.\xe2\xce\xbd\x8b4\xf8\x0f\x12Z\xdc\t\xd9\x8aRA4\x10H1\xb4\xe7\xcc\x9c\xfb\x98\x99;:3-\x95\xda\xfb\xc1\xe0}\xcc}\x9d{^\x13_Mo|\xff\t\x16\x8b\x81\xd7\xfc\xd7b\x89`\x95\xc3\x12\x8bU\x0eK,\xe6\x9c\xa3<\x05wk\x0eW\x98\xf3\x01\xcc\x1c\x8d\xb8b\xf9\x1f\x08y\x8e\x1c\xecm\xcfE\x15\x83(\xa1\xc2\x1cNA\x9d\xab\x96\x97O@9\xea\xeb\xb3\xd0(\xf8\xe5~\xe7\x16f6o\xfc\xe7Xx\x0c\x07\x9a\xdby\xa8p\xcd\xf2\xb2Qae>\x0f\xbd\xad<\xb8T6\x84\x90\xfa\xfa\x1c4KT\x1aC\xf3\xe0\x1e\x1b\x94"\x05\x19Ac\xf3\x07\xac\xa0\x97\xa9a\x8d\x94\xac|:\x0e\x86\xaa\xeb!,\xed\x8faG{\xe7#L\xc3Y5\xe7\xf7{s\x0c\xa0\xe5\x95\x1d8\t\xcf\x15\xa2\xb2<\xcbci\xdc\x10\x16\xb7S\xee\xedI\xd4\x1e\xc2D\xe6\xd0\xe5\xc8\xb4\x8fo`\xb5\xc7\x95p\xc8\xf6d1\x84.W\x83\x98\xd6%\xf9\xdf\xc2\xee\xa5_S\xf7\xa2a\x9a\xd3\xb0/\x0f\xf9nT\xce\xcas\x14sr`\xfb[4\xb7h\xc9\xb6\x1c,\x14\xb9\x98\x18\\8\xa0\x18\xa1\x8d\x97t\xc5 \xfe\x1d\x0f\xe5V\xa7ao\xde/\x93\x92\xde\x99.\x80\xf1\xfa\xc3!\xbb\x90\x87\xb3Tg\xcdAc\xeb\x89\xf0Ns\xae\x87\xd6\xd1\xee7)R9*\xc5\t.\x8d\xe1\xe2\x8a\x8b:Wc\xe8s\xd1E\xe5\xd8\xdd\xf7CN\xe3\x9c\x1b\xe9\xd2\xbd0$,^QY\xce\xb3\xf6\xa3\xe5\x1a\xac\xc4-<\xa0E\xfb\xf3-u\xd8\n\xf1\x80;e\xbf\x98\x8eq\xaa\xbd\xa5\x85\xac*\x18j\x05\x0e\xec\x08\x05\x97\xeb\xe1s0\x84\x0bjC\xcb\xfd\xcc\xfd\xe4I\xbc>\xdcO\x9b\x1ab\xcf:\x82U1\x0f>R6\x1a\xad#\xd5\xef=b_\xa5\xc9\x80\x02\xc9\xfb\xa5\xa8\x80\xefI\xd9<\x82T\x8e\xee\xd5\x03\x97b<\x83\xa6y}T\x94\xc4\xe0\xc1\x95P\xcc\x97\xd3\xef\x0ce{\xf7\xebH*a\x18\xb7\x8a\x96w\x88\t3?\xbde\xdd\xdb\xa4\'\xcb|r\x0c{\x80\xf61\xbb\xf8\xf2$\x1b\x00\xba\xfd\x96f\x00\x97C\xd8\xa5\x90\xa2\xc9\xaf\xb6&\xd6T!\xc3\xc5~#\x14\x0ex\x7f\xc2\xbb\x06\xe4Ha\x8a\xfb\xf5}\x01L\xc0"{4\xe2m\xc1\x1f\xdb\xbf\x16\xf7\x1c\x8f8\xa3\n+\x9ag\xa8\xbd\x0b\xb9$\xa4.\xdbb<K\x0cn\xc9\x91B\x89\x15@F\xe8\x10\'\x99\xbc\x8b\x99,\xf3\xd5\xd6\xfe\xfe\x17\\\xed=\x87\xa1p\x1e\xa7{\x8e\x00\x0e\xacp^\x92\xc6\xb0\x95r\xa0\x86\x7f\x12\xae\x06?[\x03V\x84\x9b\x90I\xcf9Z\x02\'CI 7,\xdca\x9c\xf0\xddj^\n\xb8\xfeA\xc4\xec\xa8\x12J\x97.\xdc1\xf2;\n\x97e\xbe\xe8\x18\x076HV\xd2\xb80\'\xa8k9\x04Z\xfe\x1e\x9dY3>\x15V\xd4\x13\x9b\x18\xe3\xbd\x94\xc5{\x18\xa2\xbc98\x0c\xc9P\xa1\xe5q\xca\x88\x15*\xac\'3lqF\xa5\x1cH\xebH\x13\x92p\x9f\xba\xab\xa2Md\xf8!\xac{z\x0f\xcdk\xbfl\xb64L@y\xad\xc7\x94P\xedI\xb9\xe3T!.D\x96\xf9b\xc7\xe8\xc6E\t!\x9f\x87\x12\xd4\x05j\xd3\xfaUX\xe1\'.!\xd5B\x8a\x98K7\x1c\x99\nh\xebm\xbc\xd1\xf7\xef\xffn%\x93\xfd\x84\x86-\xce\x18P\x0e\x91\x00\x99\x12\x1fO\x9b\x0c\xc9d20I\xc48\xec[\x0e)BPA\xfa\x9d\x81T\x1e\x8f\x84\xbf\xc6\xd2\x9e\xe4\'\xe2\x1f \xcb|\xfa\x18/94\xbau\x1f\xea7\xc96\x1d\xda\xa7lo\x10L,Qn\xe5/19E\x06\xc3~\xc6\x7f\xd9?\xfd\xfb\x85\xe5y\ty\x0e\x8bEa\x95\xc3\x12\x03\xc0/(;\x1c\xb9\xd6Y\x83\xb5\x00\x00\x00\x00IEND\xaeB`\x82'
    __img_notepad = b'\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x01\x00\x00\x00\x00\xe7\x08\x06\x00\x00\x00\xf1D\x88\xe8\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\tpHYs\x00\x00\x12t\x00\x00\x12t\x01\xdef\x1fx\x00\x00\x02\xd4IDATx^\xed\xd41\x01\xc00\x0c\xc0\xb0t\xfc\t\xe7j\x9f\xb1\xb0\xf4\x98\x81\xcf\xee\xde\x01\x92\xbe\xbf@\x90\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\x98\x01@\xd6\xcc\x03L\xf1\x05\xb8\xe9\xd2a\xa3\x00\x00\x00\x00IEND\xaeB`\x82'

    __images = (
        __img_1,
        __img_2,
        __img_3,
        __img_4,
        __img_5,
        __img_6,
        __img_7,
        __img_notepad
    )

    def __init__(self):
        self.__check_folder()

    def __check_folder(self):
        if not self.__folder_name.exists():
            Path.mkdir(self.__folder_name)

    def create_buttons_images(self):
        for i in range(len(self.__images)):
            with open(f'{self.__folder_name}/{i + 1}.png', 'wb') as img_file:
                img_file.write(self.__images[i])


if __name__ == '__main__':
    ZoomStarter().run()
